[PATCH] D125172: [clangd] Disable predefined macros in tests. NFC

Sam McCall via Phabricator via cfe-commits cfe-commits at lists.llvm.org
Mon May 9 05:45:09 PDT 2022


This revision was automatically updated to reflect the committed changes.
sammccall marked an inline comment as done.
Closed by commit rGbf9921adb930: [clangd] Disable predefined macros in tests. NFC (authored by sammccall).

Changed prior to commit:
  https://reviews.llvm.org/D125172?vs=427875&id=428046#toc

Repository:
  rG LLVM Github Monorepo

CHANGES SINCE LAST ACTION
  https://reviews.llvm.org/D125172/new/

https://reviews.llvm.org/D125172

Files:
  clang-tools-extra/clangd/unittests/IncludeCleanerTests.cpp
  clang-tools-extra/clangd/unittests/TestTU.cpp


Index: clang-tools-extra/clangd/unittests/TestTU.cpp
===================================================================
--- clang-tools-extra/clangd/unittests/TestTU.cpp
+++ clang-tools-extra/clangd/unittests/TestTU.cpp
@@ -40,7 +40,9 @@
   ParseInputs Inputs;
   Inputs.FeatureModules = FeatureModules;
   auto &Argv = Inputs.CompileCommand.CommandLine;
-  Argv = {"clang"};
+  // In tests, omit predefined macros (__GNUC__ etc) for a 25% speedup.
+  // There are hundreds, and we'd generate, parse, serialize, and re-parse them!
+  Argv = {"clang", "-Xclang", "-undef"};
   // FIXME: this shouldn't need to be conditional, but it breaks a
   // GoToDefinition test for some reason (getMacroArgExpandedLocation fails).
   if (!HeaderCode.empty()) {
Index: clang-tools-extra/clangd/unittests/IncludeCleanerTests.cpp
===================================================================
--- clang-tools-extra/clangd/unittests/IncludeCleanerTests.cpp
+++ clang-tools-extra/clangd/unittests/IncludeCleanerTests.cpp
@@ -386,9 +386,9 @@
 
     using flags::FLAGS_FOO;
 
     // CLI will come from a define, __llvm__ is a built-in. In both cases, they
     // come from non-existent files.
-    int y = CLI + __llvm__;
+    int y = CLI + __cplusplus;
 
     int concat(a, b) = 42;
     )cpp";


-------------- next part --------------
@@ -386,9 +386,9 @@
     using flags::FLAGS_FOO;
 
-    // CLI will come from a define, __llvm__ is a built-in. In both cases, they
+    // CLI will come from a define, __cplusplus is a built-in. In both cases, they
     // come from non-existent files.
A non-text attachment was scrubbed...
Name: D125172.428046.patch
Type: text/x-patch
Size: 1370 bytes
Desc: not available
URL: <http://lists.llvm.org/pipermail/cfe-commits/attachments/20220509/6550062f/attachment.bin>


More information about the cfe-commits mailing list